<?php

if (!isset($_SESSION["role"]))
	require_once "server_files/403.php";

$id = $_GET["id"];
$user = User::fromId($id);

if ($_SESSION["role"] != Role::ADMIN) {
	if ($user->getId() != $_SESSION["user_id"])
		require_once "server_files/403.php";
}

if ($user === null)
	require_once "server_files/404.php";

$team = Team::fromId($user->getTeamId());

$has_error = false;
$error_message = null;

if (isset($_POST["kick"])) {
	if ($team == null) {
		$has_error = true;
		$error_message = "La personne à expulser n'est dans aucune équipe.";
	}
	else {
		quitTeam($id);
		$team = null;
	}
}

if (isset($_POST["attribute_team"])) {
	$attribute_team = new AttributeTeam($_POST);
	try {
		$attribute_team->makeVerifications();
		$attribute_team->attribute();
	} catch (AssertionError $e) {
		$has_error = true;
		$error_message = $e->getMessage();
	}
}

class AttributeTeam
{
    private $team_id;
	private $team;
	private $min_null_index;

	public function __construct($data)
	{
		$this->team_id = $data["team"];
		$this->team = Team::fromId($this->team_id);
	}

	public function makeVerifications()
	{
		global $user;

		ensure($user->getConfirmEmailToken() == null, "Ce participant n'a pas encore validé son adresse e-mail.");
		ensure($this->team_id != "no_team", "Vous n'avez pas choisi d'équipe.");
		ensure($this->team != null, "Cette équipe n'existe pas.");
		ensure($this->team->getValidationStatus() == ValidationStatus::NOT_READY, "Cette équipe est déjà validée ou en cours de validation.");

		$role = $user->getRole();
		for ($i = 1; $i <= $role == Role::ENCADRANT ? 1 : 5; ++$i) {
			if (($role == Role::PARTICIPANT ? $this->team->getParticipants()[$i - 1] : $this->team->getEncadrantId()) == NULL)
				break;
		}

		$this->min_null_index = $i;

		ensure($role == Role::PARTICIPANT && $this->min_null_index <= 5 || $role == Role::ENCADRANT && $this->min_null_index <= 2,
			"Il n'y a plus de place pour vous dans l'équipe.");
	}

	public function attribute()
	{
		global $user, $team;

		$user->setTeamId($this->team->getId());

		if ($user->getRole() == Role::ENCADRANT)
			$this->team->setEncadrant($user->getId());
		else
			$this->team->setParticipant($this->min_null_index, $user->getId());

		Mailer::sendJoinTeamMail($user, $this->team);

		$team = $this->team;
	}
}

if ($team != null)
	$documents = $user->getAllDocuments();

require_once "server_files/views/informations.php";
